<?php
/**
 * blogtrip functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package blogtrip
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function blogtrip_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on blogtrip, use a find and replace
		* to change 'blogtrip' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'blogtrip', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	
	add_theme_support( 'automatic-feed-links' );

	add_theme_support( 'register_block_style' );

	add_theme_support( 'register_block_pattern' );
	
	add_theme_support( 'responsive-embeds' );

	add_theme_support( 'align-wide' );

	add_theme_support( 'wp-block-styles' );
	
	add_theme_support( 'editor-styles' );

	// add_editor_styles
	
	function blogtrip_add_editor_styles() {
    	add_editor_style( get_template_directory_uri() . '/css/editor-style.css' );
	}
	add_action('admin_init', 'blogtrip_add_editor_styles');

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'blogtrip' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'blogtrip_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'blogtrip_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function blogtrip_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'blogtrip_content_width', 640 );
}
add_action( 'after_setup_theme', 'blogtrip_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function blogtrip_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'blogtrip' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'blogtrip' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'header-1', 'blogtrip' ),
			'id'            => 'header-1',
			'description'   => esc_html__( 'Add widgets here.', 'blogtrip' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'header-2', 'blogtrip' ),
			'id'            => 'header-2',
			'description'   => esc_html__( 'Add widgets here.', 'blogtrip' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'header-3', 'blogtrip' ),
			'id'            => 'header-3',
			'description'   => esc_html__( 'Add widgets here.', 'blogtrip' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'blogtrip_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function blogtrip_scripts() {

	wp_enqueue_style( 'blogtrip-fontawesome-style', get_template_directory_uri() . '/assets/css/all.css', array(), '5.15.4');

	wp_enqueue_style('blogtrip-block-css', get_template_directory_uri() . '/assets/css/block.css');
	
	wp_enqueue_style('blogtrip-editor-style-css', get_template_directory_uri() . '/assets/css/editor-style.css');

	wp_enqueue_script('blogtrip-custom-script', get_stylesheet_directory_uri() . '/js/custom.js',array( 'jquery' ));

	wp_enqueue_style( 'blogtrip-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'blogtrip-style', 'rtl', 'replace' );

	wp_enqueue_script( 'blogtrip-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'blogtrip_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * custom excerpt length and read-more
 */

function blogtrip_custom_excerpt_length( $length ) {
	if ( ! is_admin() )
	return 30;
}

add_filter( 'excerpt_length', 'blogtrip_custom_excerpt_length', 999 );

function blogtrip_excerpt_more( $more ) {
    return '......';
}
add_filter( 'excerpt_more', 'blogtrip_excerpt_more' );

