<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package blogtrip
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'blogtrip' ); ?></a>

	<header id="masthead" class="site-header">
		<div class="site-branding">
			<div class="site-branding-logo">
				<?php the_custom_logo(); ?>
			</div><!-- .site-branding-logo -->
			<div class="site-branding-text">

					<?php if ( is_front_page() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php endif; ?>

					<?php
					$description = get_bloginfo( 'description', 'display' );

					if ( $description || is_customize_preview() ) :
						?>
						<p class="site-description"><?php echo esc_html( $description ); ?></p>
					<?php endif; ?>
				
			</div><!-- .site-branding-text -->
		</div><!-- site-branding -->
		<nav id="site-navigation" class="main-navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
					<?php esc_html_e( '', 'blogtrip' ); ?>
					<span></span>
					<span></span>
					<span></span>
				</button>
			<?php
			wp_nav_menu(
				array(
					'theme_location' => 'menu-1',
					'menu_id'        => 'primary-menu',
				)
			);
			?>
		</nav><!-- #site-navigation -->

		
	</header><!-- #masthead -->
	<div class="top-content">
		<!-- top widgets -->
		<div class="header-widgets-wrapper">
			<?php if ( is_active_sidebar( 'header-1' ) ) : ?>
				<div class="header-widgets-three header-widgets-left">
					<?php dynamic_sidebar( 'header-1' ); ?>
				</div>
			<?php endif; ?>

			<?php if ( is_active_sidebar( 'header-2' ) ) : ?>
				<div class="header-widgets-three header-widgets-middle">
					<?php dynamic_sidebar( 'header-2' ); ?>
				</div>
			<?php endif; ?>

			<?php if ( is_active_sidebar( 'header-3' ) ) : ?>
				<div class="header-widgets-three header-widgets-right">
					<?php dynamic_sidebar( 'header-3' ); ?>				
				</div>
			<?php endif; ?>
		</div>
	</div>
